@@ -1,24 +1,18 @@
-# future imports
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import annotations
 
-# stdlib imports
 import logging
 
-# third-party imports
 import pykka
 
-# local imports
-from .reporters import events
-from .reporters import status
+from .reporters import events, status
+
 
 logger = logging.getLogger(__name__)
 
 
 class WebhookFrontend(pykka.ThreadingActor):
-
     def __init__(self, config, core):
-        super(WebhookFrontend, self).__init__()
+        super().__init__()
         self.config = config
         self.core = core
         self.event_reporter = None
@@ -26,11 +20,17 @@ class WebhookFrontend(pykka.ThreadingActor):
 
     def on_start(self):
         self.event_reporter = events.EventReporter.start(self.config)
-        self.status_reporter = status.StatusReporter.start(self.config, self.core)
+
+        if self.config["webhooks"]["status_update_interval"] > 0:
+            self.status_reporter = status.StatusReporter.start(self.config, self.core)
+        else:
+            logger.info("Webhooks StatusReporter disabled by configuration.")
 
     def _stop_children(self):
         self.event_reporter.stop()
-        self.status_reporter.stop()
+
+        if self.status_reporter:
+            self.status_reporter.stop()
 
     def on_stop(self):
         self._stop_children()
